<?php
namespace SM\Factory;

use Doctrine\ORM\EntityManager;

class ExemploFactory
{
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager)
    {
        
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * A função "validaEscopoProposta" verifica se o escopo
     * que está sendo relacionado já está relacionado ao modelo.
     */
    
    public function validaEscopoProposta($params)
    {
        
        $sql = "SELECT COUNT(*) AS VALIDAESCOPO
                  FROM FCT_RELACESCOPOMODELO
                 WHERE NRTIPOORCAMENTO IN (".$params['NRTIPOORCAMENTO'].")
                   AND NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                   AND NRORG = :NRORG";

        unset($params['NRTIPOORCAMENTO']);
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
    /**
     * Deleta o documento de determinada situação ligada a um escopo
    **/
    public function excluirDocumentoSituacao($idSituacao, array $params)
    {
        $sql = "DELETE FROM FCT_ORCAESCOPODOC
                WHERE IDSITUACAOORCAMENTO IN('$idSituacao')
                    AND NRRELACESCOPOMODELO = :NRRELACESCOPOMODELO
                    AND NRORG               = :NRORG";
        $this->connection->executeStatement($sql, $params);
    }
    /**
     * Edita as informações de um documento ligado a um escopo
    **/
    public function editarDocumentoSituacao($idSituacao, array $params)
    {
        $sql = "UPDATE FCT_ORCAESCOPODOC
                SET NRSEQMODDOCFCT = :NRSEQMODDOCFCT,
                    IDPERMITEDOCX  = :IDPERMITEDOCX,
                    CDOPERULTATU   = :CDOPERADOR,
                    NRORGULTATU    = :NRORG,
                    DTULTATU       = SYSDATE
                WHERE NRRELACESCOPOMODELO = :NRRELACESCOPOMODELO
                    AND NRORG             = :NRORG
                    AND IDSITUACAOORCAMENTO IN('$idSituacao')";
        $this->connection->executeStatement($sql, $params);
    }
    /**
     * Insere um modelo de docuemnto para uma determinada situação
    **/
    public function inserirDocumentoSituacao(array $params)
    {
        $sql = "INSERT INTO FCT_ORCAESCOPODOC (
                    NRORCAESCOPODOC,     NRRELACESCOPOMODELO, NRSEQMODDOCFCT,
                    IDSITUACAOORCAMENTO, NRORG,               IDATIVO,
                    DTINCLUSAO,          DTULTATU,            NRORGINCLUSAO,
                    CDOPERINCLUSAO,      NRORGULTATU,         CDOPERULTATU,
                    IDPERMITEDOCX
                ) VALUES (
                    :NRORCAESCOPODOC,     :NRRELACESCOPOMODELO, :NRSEQMODDOCFCT,
                    :IDSITUACAOORCAMENTO, :NRORG,               :IDATIVO,
                    SYSDATE,               NULL,                :NRORG,
                    :CDOPERADOR,           NULL,                 NULL,
                    :IDPERMITEDOCX
                )";
        $this->connection->executeStatement($sql, $params);
    }
    /**
     * Retorna os modelos de documento dos escopo por situação
    **/
    public function getModeloDocumentoSituacao($idSituacao, array $params)
    {
        $sql = "SELECT LISTAGG(IDSITUACAOORCAMENTO, ', ') WITHIN GROUP (ORDER BY IDSITUACAOORCAMENTO) AS IDSITUACAOORCAMENTO 
                FROM FCT_ORCAESCOPODOC ORCDOC
                JOIN FCT_MODELODOC DOC
                    ON ORCDOC.NRSEQMODDOCFCT = DOC.NRSEQMODDOCFCT
                    AND ORCDOC.NRORG         = DOC.NRORG
                WHERE ORCDOC.NRORG                 = :NRORG
                    AND ORCDOC.NRRELACESCOPOMODELO = :NRRELACESCOPOMODELO
                    AND ORCDOC.IDSITUACAOORCAMENTO IN('$idSituacao') 
                    AND DOC.IDDOCRENEGOCIACAO = (SELECT IDDOCRENEGOCIACAO 
                                               FROM FCT_MODELODOC
                                               WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT)";
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
        /**
     * Deleta o ultimo documento com situação nula inserido
    **/
    public function deletarSituacaoNula(array $params)
    {
        $sql = "DELETE FROM FCT_ORCAESCOPODOC
                 WHERE NRORG                = :NRORG
                    AND NRRELACESCOPOMODELO = :NRRELACESCOPOMODELO
                    AND IDSITUACAOORCAMENTO IS NULL";
        
        $this->connection->executeStatement($sql, $params);
    }

    /**
     * valida se o Token do Certsign está preenchido
    **/
    public function validaTokenCertsign(array $params)
    {
        $sql = "SELECT DSTOKENCERTSIGN 
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
    
    /**
     * Busca os signatários padrões de modelo de proposta da parametrização SM
    **/
    public function buscaSignatariosPadroes(array $params)
    {
        $sql = "SELECT NRSIGNATARIOSPADR, NRPARCNEGOCIO, IDTIPOASSINATURA, IDTESTEMUNHA, NRORDENACAO, 
                       IDINSERCAOAUTO, IDTPSIGNATARIO, DSEMAILNOTSIGNENV, DSEMAILNOTIFOUTROS, NRORG 
                  FROM FCT_SIGNATARIOSPADR
                 WHERE IDINSERCAOAUTO IN ('P','A')
                   AND NRORG = :NRORG";
        
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
    
    
    /**
     * insere os signatários padrões de modelo de proposta que foram buscados na parametrização SM
    **/
    public function insereSignatariosPadroes(array $params)
    {
        
        $sql = "INSERT INTO FCT_SIGNATPADRMODORCA (NRSIGNATPADRORCA, NRORCAMENTOMODELO, NRPARCNEGOCIO, IDTIPOASSINATURA, IDTESTEMUNHA,
                                                   NRORDENACAO,  IDTPSIGNATARIO, DSEMAILNOTSIGNENV, DSEMAILNOTIFOUTROS, NRORG, DTINCLUSAO, 
                                                   CDOPERINCLUSAO, NRORGINCLUSAO, IDATIVO)
                            VALUES (:NRSIGNATPADRORCA, :NRORCAMENTOMODELO, :NRPARCNEGOCIO, :IDTIPOASSINATURA, :IDTESTEMUNHA, 
                                    :NRORDENACAO, :IDTPSIGNATARIO, :DSEMAILNOTSIGNENV, :DSEMAILNOTIFOUTROS, :NRORG, SYSDATE,
                                    :OPERADOR, :NRORG, 'S')";
                             
        
        $this->connection->executeStatement($sql, $params);
    }
    
    /**
     * A função "validaSignatCadastrados" realiza a validação dos signatários padrões para evitar a inclusão repetida de um parceiro.
     */
    public function validaSignatCadastrados(array $params)
    {
        
        $sql = "SELECT COUNT (*) AS VALIDA
                  FROM FCT_SIGNATPADRMODORCA
                 WHERE NRORCAMENTOMODELO = :NRORCAMENTOMODELO 
                   AND (((IDTPSIGNATARIO = 'SE') AND (NRPARCNEGOCIO = :NRPARCNEGOCIO))
                    OR (((IDTPSIGNATARIO <>'SE')) AND (IDTPSIGNATARIO = :IDTPSIGNATARIO)))
                   AND NRORG = :NRORG";
        
        
        $retorno = $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
        return $retorno[0]["VALIDA"];
    }
    
     /**
     * deleta os operadores de notificação de assinatura
    **/
    public function deletaOperadoresNotifica(array $params)
    {
        
        $sql = "DELETE FROM FCT_RELACOPERNOTIFASSELE
                 WHERE NRSIGNATPADRORCA = :NRSIGNATPADRORCA
                   AND NRORG = :NRORG";
                             
        $this->connection->executeStatement($sql, $params);
    }
    
    
    /**
     * insere os operadores de notificação de assinatura
    **/
    public function insereOperadoresNotifica(array $params)
    {
        
        $sql = "INSERT INTO FCT_RELACOPERNOTIFASSELE
                    (NRRELOPERNOTIFASSELE, NRSIGNATPADRORCA, CDOPERADOR, NRORG, IDATIVO,            
                	 DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
                VALUES 
                    (:NRRELOPERNOTIFASSELE, :NRSIGNATPADRORCA, :CDOPERADOR, :NRORG, 'S',             
                	 SYSDATE, :OPERADOR, :NRORG)";
                             
        $this->connection->executeStatement($sql, $params);
    }
    
    /**
     * Busca os operadores padrões para notificação de modelo de proposta da parametrização SM
    **/
    public function buscaOperadoresNotif(array $params)
    {
        $sql = "SELECT CDOPERADOR 
                  FROM FCT_RELACOPERNOTIFASSELE
                 WHERE NRSIGNATARIOSPADR = :NRSIGNATARIOSPADR
                   AND NRORG = :NRORG";
        
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
}
