<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use \Teknisa\Model\Traits\TQuery;

class Sm00005000TabParametrizacoesSignatariosPadroesFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getSignatariosPadroes()
    {
        $sql = "SELECT FCT_SIGNATARIOSPADR.NRSIGNATARIOSPADR,
                    FCT_SIGNATARIOSPADR.NRPARCNEGOCIO,
                    PARCNEGOCIO.NMPRINCIPALPARC,
                    PARCNEGOCIO.NRINSCRICAOPARC,
                    FCT_SIGNATARIOSPADR.IDTIPOASSINATURA,
                    FCT_SIGNATARIOSPADR.IDTESTEMUNHA,
                    FCT_SIGNATARIOSPADR.NRORDENACAO,
                    FCT_SIGNATARIOSPADR.IDINSERCAOAUTO,
                    FCT_SIGNATARIOSPADR.IDATIVO,
                    FCT_SIGNATARIOSPADR.NRORG,
                    FCT_SIGNATARIOSPADR.DTINCLUSAO,
                    FCT_SIGNATARIOSPADR.NRORGINCLUSAO,
                    FCT_SIGNATARIOSPADR.CDOPERINCLUSAO,
                    FCT_SIGNATARIOSPADR.DTULTATU,
                    FCT_SIGNATARIOSPADR.NRORGULTATU,
                    FCT_SIGNATARIOSPADR.CDOPERULTATU,
                    FCT_SIGNATARIOSPADR.IDTPSIGNATARIO,
                    FCT_SIGNATARIOSPADR.DSEMAILNOTSIGNENV,
                    FCT_SIGNATARIOSPADR.DSEMAILNOTIFOUTROS,
            (SELECT RTRIM(XMLAGG(XMLELEMENT(E, CDOPERADOR, ',').EXTRACT('//text()')
                                    ORDER BY NRRELOPERNOTIFASSELE).GETCLOBVAL(), ',') AS NRRELOPERNOTIFASSELE
                FROM FCT_RELACOPERNOTIFASSELE
                WHERE NRSIGNATARIOSPADR = FCT_SIGNATARIOSPADR.NRSIGNATARIOSPADR
                AND NRORG = FCT_SIGNATARIOSPADR.NRORG) AS OPERADORES
            FROM FCT_SIGNATARIOSPADR
            LEFT JOIN PARCNEGOCIO ON FCT_SIGNATARIOSPADR.NRPARCNEGOCIO = PARCNEGOCIO.NRPARCNEGOCIO
            AND FCT_SIGNATARIOSPADR.NRORG = PARCNEGOCIO.NRORG
            ORDER BY FCT_SIGNATARIOSPADR.NRORDENACAO,
                    PARCNEGOCIO.NMPRINCIPALPARC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, [], [], null, null, null, array('DSEMAILNOTSIGNENV', 'OPERADORES'));
    }

    public function getParceriaOperador()
    {
        $sql = "SELECT PARCNEGOCIO.NRPARCNEGOCIO,
                        PARCNEGOCIO.NMPRINCIPALPARC,
                        PARCNEGOCIO.NRINSCRICAOPARC,
                        PARCNEGOCIO.NMSECUNDARIPARC,
                        OPERADOR.CDOPERADOR,
                        PARCNEGOCIO.NRORG
                FROM PARCNEGOCIO
                JOIN PARCERIA ON PARCNEGOCIO.NRPARCNEGOCIO = PARCERIA.NRPARCNEGOCIO
                AND PARCNEGOCIO.NRORG = PARCERIA.NRORG
                AND PARCNEGOCIO.IDATIVO = PARCERIA.IDATIVO
                AND PARCERIA.CDTIPOPARCEIRO = 'OPERADOR'
                AND PARCERIA.IDATIVO = 'S'
                JOIN OPERADOR ON PARCNEGOCIO.NRPARCNEGOCIO = OPERADOR.NRPARCNEGOCIO
                AND PARCNEGOCIO.NRORG = OPERADOR.NRORG
                AND OPERADOR.IDOPERATIVO = 'A'
                WHERE PARCNEGOCIO.CDTIPOINSCRICAO = 'CPF'
                AND PARCNEGOCIO.IDATIVO = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function validaDuplicadosSignatarios($params)
    {

        $sql = "SELECT COUNT (*) AS QTD 
                FROM FCT_SIGNATARIOSPADR
                WHERE NRPARCNEGOCIO      = :NRPARCNEGOCIO
                AND NRSIGNATARIOSPADR <> NVL(:NRSIGNATARIOSPADR, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function validaDuplicadosTpSignatarios($params)
    {

        $sql = "SELECT COUNT (*) AS QTD 
                FROM FCT_SIGNATARIOSPADR
                WHERE IDTPSIGNATARIO      = :IDTPSIGNATARIO
                AND NRSIGNATARIOSPADR <> NVL(:NRSIGNATARIOSPADR, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function updateSignatariosPadrao($params)
    {
        $sql = "UPDATE FCT_SIGNATARIOSPADR
                   SET IDTIPOASSINATURA   = :IDTIPOASSINATURA,
                       IDTESTEMUNHA       = :IDTESTEMUNHA,
                       NRORDENACAO        = :NRORDENACAO, 
                       IDINSERCAOAUTO     = :IDINSERCAOAUTO,
                       NRORG              = :NRORG,
                       DTULTATU           = SYSDATE,
                       CDOPERULTATU       = :CDOPERULTATU,
                       IDATIVO            = :IDATIVO,
                       IDTPSIGNATARIO     = :IDTPSIGNATARIO,
                       DSEMAILNOTSIGNENV  = :DSEMAILNOTSIGNENV,
                       DSEMAILNOTIFOUTROS = :DSEMAILNOTIFOUTROS
                 WHERE NRSIGNATARIOSPADR = :NRSIGNATARIOSPADR";

        $this->connection->executeStatement($sql, $params);
    }

    public function insertSignatariosPadrao(array $params)
    {
        $sql = "INSERT INTO FCT_SIGNATARIOSPADR(
                    NRSIGNATARIOSPADR, NRPARCNEGOCIO, IDTIPOASSINATURA, IDTESTEMUNHA, NRORDENACAO, IDINSERCAOAUTO, NRORG, 
                    CDOPERINCLUSAO, IDATIVO, DTINCLUSAO, IDTPSIGNATARIO, DSEMAILNOTSIGNENV, DSEMAILNOTIFOUTROS)
                VALUES(
                    :NRSIGNATARIOSPADR, :NRPARCNEGOCIO, :IDTIPOASSINATURA, :IDTESTEMUNHA, :NRORDENACAO, :IDINSERCAOAUTO, :NRORG, 
                    :CDOPERINCLUSAO, :IDATIVO, SYSDATE, :IDTPSIGNATARIO, :DSEMAILNOTSIGNENV, :DSEMAILNOTIFOUTROS)";

        $this->connection->executeStatement($sql, $params);
    }

    public function deletaOperadoresNotifica(array $params)
    {
        
        $sql = "DELETE FROM FCT_RELACOPERNOTIFASSELE
                 WHERE NRSIGNATARIOSPADR = :NRSIGNATARIOSPADR
                   AND NRORG = :NRORG";
                             
        $this->connection->executeStatement($sql, $params);
    }

    public function insereOperadoresNotifica(array $params)
    {
        $sql = "INSERT INTO FCT_RELACOPERNOTIFASSELE
                    (NRRELOPERNOTIFASSELE, NRSIGNATARIOSPADR, CDOPERADOR, NRORG, IDATIVO,            
                	 DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
                VALUES 
                    (:NRRELOPERNOTIFASSELE, :NRSIGNATARIOSPADR, :CDOPERADOR, :NRORG, 'S',             
                	 SYSDATE, :OPERADOR, :NRORG)";
                             
        $this->connection->executeStatement($sql, $params);
    }

    public function deleteParametrosSignatario($params)
    {
        $sql = "DELETE FROM FCT_SIGNATARIOSPADR WHERE NRSIGNATARIOSPADR = :NRSIGNATARIOSPADR";
        $this->connection->executeStatement($sql, $params);
    }

    public function validaTokenCertsign(array $params)
    {
        $sql = "SELECT DSTOKENCERTSIGN 
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function validaSignatCadastrados(array $params)
    {
        
        $sql = "SELECT COUNT (*) AS VALIDA
                  FROM FCT_SIGNATARIOSPADR
                 WHERE (((IDTPSIGNATARIO = 'SE') AND (NRPARCNEGOCIO = :NRPARCNEGOCIO))
                    OR (((IDTPSIGNATARIO <>'SE')) AND (IDTPSIGNATARIO = :IDTPSIGNATARIO)))
                   AND NRORG = :NRORG";
        
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function insereSignatariosPadroesCadAuto(array $params)
    {
        $sql = "INSERT INTO FCT_SIGNATARIOSPADR (
                    NRSIGNATARIOSPADR,  NRPARCNEGOCIO,      IDTIPOASSINATURA,
                    IDTESTEMUNHA,       NRORDENACAO,        IDINSERCAOAUTO,
                    IDTPSIGNATARIO,     DSEMAILNOTSIGNENV,  DSEMAILNOTIFOUTROS,
                    NRORG,              DTINCLUSAO,         CDOPERINCLUSAO,
                    NRORGINCLUSAO,      IDATIVO
                )
                VALUES (
                    :NRSIGNATARIOSPADR, :NRPARCNEGOCIO,     :IDTIPOASSINATURA,
                    :IDTESTEMUNHA,      :NRORDENACAO,       :IDINSERCAOAUTO,
                    'SE',               :DSEMAILNOTSIGNENV, :DSEMAILNOTIFOUTROS,
                    :NRORG,             SYSDATE,            :OPERADOR,
                    :NRORG,             'S'
                )";
        $this->connection->executeStatement($sql, $params);
    }
}
